@@ -485,13 +485,17 @@ class ParametersLEDET:
         """
         if(type(variableGroup) != dict):
             for k in variableGroup.__annotations__:
+                if (k == "BlankRows"): continue
                 print(k, self.getAttribute(variableGroup, k))
         else:
             self.variableGroupInputs = asdict(self.Inputs)
+            print(self.variableGroupInputs)
             self.variableGroupOptions = asdict(self.Options)
             self.variableGroupPlots = asdict(self.Plots)
             self.variableGroupVariables = asdict(self.Variables)
             for k in variableGroup:
+                if (k == "BlankRows"): continue
+                print(variableGroup[k])
                 print(k, variableGroup[k])
 
     def getNumberOfCoilSections(self):
@@ -714,7 +718,7 @@ class ParametersLEDET:
             if (attribute == "overwrite_f_externalVoids_inGroup"):
                 ofiVg = self.getAttribute(variableGroup, attribute)
                 if len(ofiVg) == 0:
-                    #currentRow = currentRow + 1
+                    currentRow = currentRow + 1
                     continue
             if currentRow in variableGroup.BlankRows[1]:
                 currentRow = currentRow + 1
