@@ -452,9 +452,13 @@ class ParametersCOSIM:
         for i in range(N_LEDET):
             # Copy LEDET model files - MCD
             if N_LEDET > 1:
-                nameFolderLedetModel = os.path.join(nameFolderCosimModel, 'LEDET_'+str(i))
-                sourcedir = LEDETFiles[i]
-                sourcefiles = os.listdir(LEDETFiles[i])
+                nameFolderLedetModel = os.path.join(nameFolderCosimModel, 'LEDET_'+str(i+1))
+                if len(LEDETFiles)>1:
+                    sourcedir = LEDETFiles[i]
+                    sourcefiles = os.listdir(LEDETFiles[i])
+                else:
+                    sourcefiles = os.listdir(LEDETFiles)
+                    sourcedir = LEDETFiles
                 nM = nameMagnet[i]
             else:
                 nameFolderLedetModel = os.path.join(nameFolderCosimModel, 'LEDET')
